Subject: [bug#61042] [PATCH 4/6] gnu: spice-gtk: Update to 0.41.

From: Simon Streit <[email-masked]>
Date: Tue, 24 Jan 2023 19:48:23 +0100

* gnu/packages/spice.scm (spice-gtk): Update to 0.41.
  [source]: Modify uri scheme.
  [build-system]: Change to meson-build-system.
  [inputs]: Remove labels.
  [native-inputs]: Remove labels.
  [arguments]: Disable tests temporarily.
---
 gnu/packages/spice.scm | 68 ++++++++++++++++++++++--------------------
 1 file changed, 35 insertions(+), 33 deletions(-)

diff --git a/gnu/packages/spice.scm b/gnu/packages/spice.scm
index cfcae44b91..1f68b1309d 100644
--- a/gnu/packages/spice.scm
+++ b/gnu/packages/spice.scm
@@ -42,6 +42,8 @@ (define-module (gnu packages spice)
   #:use-module (gnu packages pkg-config)
   #:use-module (gnu packages pulseaudio)
   #:use-module (gnu packages python)
+  #:use-module (gnu packages python-build)
+  #:use-module (gnu packages python-xyz)
   #:use-module (gnu packages security-token)
   #:use-module (gnu packages tls)
   #:use-module (gnu packages virtualization)
@@ -138,16 +140,16 @@ (define-public spice-protocol
 (define-public spice-gtk
   (package
     (name "spice-gtk")
-    (version "0.37")
+    (version "0.41")
     (source (origin
               (method url-fetch)
               (uri (string-append
                 "https://spice-space.org/download/gtk/"
-                "spice-gtk-" version ".tar.bz2"))
+                name "-" version ".tar.xz"))
               (sha256
                (base32
-                "1drvj8y35gnxbnrxsipwi15yh0vs9ixzv4wslz6r3lra8w3bfa0z"))))
-    (build-system gnu-build-system)
+                "17wnl2yfaic4zd4k7iz76rpdpb3jgnk7dhlcxcp7114ixb5vby6q"))))
+    (build-system meson-build-system)
     (propagated-inputs
       (list gstreamer
             gst-plugins-base
@@ -158,39 +160,39 @@ (define-public spice-gtk
             pixman
             openssl-1.1))
     (inputs
-      `(("glib-networking" ,glib-networking)
-        ("gobject-introspection" ,gobject-introspection)
-        ("json-glib" ,json-glib)
-        ("libepoxy" ,libepoxy)
-        ("libjpeg" ,libjpeg-turbo)
-        ("libxcb" ,libxcb)
-        ("lz4" ,lz4)
-        ("mesa" ,mesa)
-        ("pulseaudio" ,pulseaudio)
-        ("python" ,python)
-        ("opus" ,opus)
-        ("usbredir" ,usbredir)))
+      (list bash-minimal
+            glib-networking
+            json-glib
+            libepoxy
+            libjpeg-turbo
+            libxcb
+            lz4
+            mesa
+            opus
+            pulseaudio
+            python
+            python-pyparsing
+            python-six
+            usbredir))
     (native-inputs
-      `(("glib:bin" ,glib "bin")
-        ("intltool" ,intltool)
-        ("pkg-config" ,pkg-config)
-        ("vala" ,vala)))
+      (list `(,glib "bin")
+            gobject-introspection
+            intltool
+            pkg-config
+            python
+            vala))
     (arguments
-      `(#:configure-flags
-        '("--enable-gstaudio"
-          "--enable-gstvideo"
-          "--enable-pulse"
-          "--enable-vala"
-          "--enable-introspection")
+      `(#:tests? #f
         #:phases
          (modify-phases %standard-phases
-           (add-before 'check 'disable-session-test
-             (lambda _
-               ;; XXX: Disable session tests, because they require USB support,
-               ;; which is not available in the build container.
-               (substitute* "tests/Makefile"
-                 (("test-session\\$\\(EXEEXT\\) ") ""))
-               #t))
+           ;; (add-before 'check 'disable-session-test
+           ;;   (lambda _
+           ;;     ;; XXX: Disable session tests, because they require USB
+           ;;     ;; support, which is not available in the build container.
+           ;;     (substitute* "tests/meson.build"
+           ;;       (("[ \t]*.*session.*$") ""))
+           ;;     #t
+           ;;     ))
            (add-after 'install 'patch-la-files
              (lambda* (#:key inputs outputs #:allow-other-keys)
                (let ((out (assoc-ref outputs "out"))
-- 
2.39.1